@@ -1,5 +1,5 @@
 from firstimpression.constants import APIS
-from firstimpressionbeta
+from firstimpressionbeta.api.request import request_json
 
 ##################################################################################################
 # CONSTANTS
@@ -15,7 +15,7 @@ GUID = 'df83c872-7416-4817-8578-80240d3e03dc'
 ##################################################################################################
 
 def run_api(guid):
-    response = requests.post(URL, params={'guid':guid}).text
+    response = request_json(URL, params={'guid':guid}, method='post')
     print(response)
 
 
